Regen
=====

.. autoclass:: physics.models.regen.BasicRegen
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: physics.models.regen.BaseRegen
   :members:
   :undoc-members:
   :show-inheritance: